@@ -1,4 +1,4 @@
-// Sample 48000 Hz, pass 1350, stop 1750, ripple 1 dB, atten 80 dB (coef_tx).
+// Sample 48000 Hz, pass 1350, stop 1750, ripple 1 dB, atten 80 dB (coef_tx).  Stop 0.036458.
 double quiskMicFilt48Coefs[325] = {
  0.000070000950338734, 0.000060542525732639, 0.000084830915167248, 0.000113820318991206, 0.000147523658260692, 
  0.000185727097247136, 0.000228017694264326, 0.000273714746744222, 0.000321902242967596, 0.000371355069437399, 
@@ -66,7 +66,7 @@ double quiskMicFilt48Coefs[325] = {
  0.000371355069437399, 0.000321902242967596, 0.000273714746744222, 0.000228017694264326, 0.000185727097247136, 
  0.000147523658260692, 0.000113820318991206, 0.000084830915167248, 0.000060542525732639, 0.000070000950338734} ;
 
-// Rate 8000, pass 1350, stop 1700, ripple 0.2 dB, Atten 100 dB, taps 93 (tune 1650)
+// Rate 8000, pass 1350, stop 1700, ripple 0.2 dB, Atten 100 dB, taps 93 (tune 1650). Stop 0.2125
 double quiskMicFilt8Coefs[93] = { -0.000048361334397216, -0.000162172832480051, -0.000233937595698212,
 -0.000006327103457766, 0.000686150429731403, 0.001555572669911020, 0.001852235322638049, 0.001010518676959113,
 -0.000533703037637750, -0.001395527281294679, -0.000547805689731835, 0.001291819787342756, 0.002005877810728077,
@@ -87,7 +87,7 @@ double quiskMicFilt8Coefs[93] = { -0.000048361334397216, -0.000162172832480051,
 -0.001395527281294679, -0.000533703037637750, 0.001010518676959113, 0.001852235322638049, 0.001555572669911020,
  0.000686150429731403, -0.000006327103457766, -0.000233937595698212, -0.000162172832480051, -0.000048361334397216} ;
 
-// Rate 48000, pass 3200, stop 4500, ripple 0.2 dB, atten 100 dB, taps 144
+// Rate 48000, pass 3200, stop 4500, ripple 0.2 dB, atten 100 dB, taps 144. Stop .09375.
 double quiskLpFilt48Coefs[144] = {-0.000017125474330604, -0.000040011820393130, -0.000077862936583202,
 -0.000127389313997705, -0.000181102741386044, -0.000225109758175834, -0.000239838685218700, -0.000202969232396477,
 -0.000094305597311178, 0.000097794345082862, 0.000369998664433527, 0.000699241419612492, 0.001041511593601482,
@@ -119,7 +119,7 @@ double quiskLpFilt48Coefs[144] = {-0.000017125474330604, -0.000040011820393130,
 -0.000225109758175834, -0.000181102741386044, -0.000127389313997705, -0.000077862936583202, -0.000040011820393130,
 -0.000017125474330604 } ;
 
-// Sample 1 Hz, pass 0.125, stop 0.192, ripple 0.1 dB, atten 100 dB, taps 64
+// Sample 1 Hz, pass 0.125, stop 0.192, ripple 0.1 dB, atten 100 dB, taps 64.  Stop 0.192.
 double quiskFilt12_19Coefs[64] = { 0.000043810351462319, 0.000138863869398690, 0.000206835545025070,
  0.000047730531591317, -0.000514727559529336, -0.001353635480056038, -0.001881242409327435, -0.001336759882352925,
  0.000480762137654505, 0.002595795305500315, 0.003157538223935716, 0.000883738175457450, -0.003304786290465149,
@@ -135,7 +135,7 @@ double quiskFilt12_19Coefs[64] = { 0.000043810351462319, 0.000138863869398690, 0
 -0.001353635480056038, -0.000514727559529336, 0.000047730531591317, 0.000206835545025070, 0.000138863869398690,
  0.000043810351462319} ;
 
-// Sample 185185 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+// Sample 185185 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.12960.
 double quiskFilt185D3Coefs[188] = { 0.000008153800001840, -0.000001771417630395, -0.000037253333929034, -0.000119009795238060,
 -0.000255018503860098, -0.000431457630502916, -0.000606779374823655, -0.000718366697089728, -0.000703620301380014,
 -0.000529751805487936, -0.000219462957628643, 0.000142545317473537, 0.000431747689511389, 0.000531458261578183,
@@ -175,7 +175,7 @@ double quiskFilt185D3Coefs[188] = { 0.000008153800001840, -0.000001771417630395,
 -0.000703620301380014, -0.000718366697089728, -0.000606779374823655, -0.000431457630502916, -0.000255018503860098,
 -0.000119009795238060, -0.000037253333929034, -0.000001771417630395, 0.000008153800001840 };
 
-// Sample 185185 Hz, pass 15000, stop 23900, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+// Sample 185185 Hz, pass 15000, stop 23900, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.129060.
 double quiskFilt185D3XCoefs[88] = { -0.000026016801458962, -0.000079343977811083, -0.000167897725115826, -0.000272158478205181,
 -0.000343785933253942, -0.000310796788289393, -0.000102311891399797, 0.000311300138822939, 0.000877228005105512, 0.001440583394256035,
  0.001767836749778265, 0.001621580974541500, 0.000871040137123456, -0.000402149294308734, -0.001857385353819294, -0.002952994474321905,
@@ -192,7 +192,7 @@ double quiskFilt185D3XCoefs[88] = { -0.000026016801458962, -0.000079343977811083
  0.001621580974541500, 0.001767836749778265, 0.001440583394256035, 0.000877228005105512, 0.000311300138822939, -0.000102311891399797,
 -0.000310796788289393, -0.000343785933253942, -0.000272158478205181, -0.000167897725115826, -0.000079343977811083, -0.000026016801458962} ;
 
-// Sample 185185 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
+// Sample 185185 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.064800.
 double quiskFilt185D7Coefs[325] = { 0.000011585872492535, 0.000021202775655724, 0.000038515581433427, 0.000062668164659740,
  0.000093940890103130, 0.000131718743859808, 0.000174225065604974, 0.000218342986026828, 0.000259582942086064, 0.000292202414812531,
  0.000309501208323850, 0.000304347853118504, 0.000269885084834102, 0.000200329336288352, 0.000091873319388286,
@@ -259,7 +259,7 @@ double quiskFilt185D7Coefs[325] = { 0.000011585872492535, 0.000021202775655724,
  0.000292202414812531, 0.000259582942086064, 0.000218342986026828, 0.000174225065604974, 0.000131718743859808,
  0.000093940890103130, 0.000062668164659740, 0.000038515581433427, 0.000021202775655724, 0.000011585872492535} ;
 
-// Sample 133333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+// Sample 133333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.18000.
 double quiskFilt133D2Coefs[136] = { 0.000017194140195307, 0.000013031580406032, -0.000070982819622986, -0.000297799318127961,
 -0.000645057684247744, -0.000951723373793975, -0.000976667009837673, -0.000579840699091521, 0.000098129751533427,
  0.000644977424009104, 0.000648591932388761, 0.000063466245825653, -0.000655952785922865, -0.000858530950797784,
@@ -289,7 +289,7 @@ double quiskFilt133D2Coefs[136] = { 0.000017194140195307, 0.000013031580406032,
 -0.000976667009837673, -0.000951723373793975, -0.000645057684247744, -0.000297799318127961, -0.000070982819622986,
  0.000013031580406032, 0.000017194140195307 } ;
 
-// Sample 133333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
+// Sample 133333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.09000.
 double quiskFilt133D5Coefs[235] = { 0.000017189993342429, 0.000044738485582654, 0.000095017992345093, 0.000171520768649681,
  0.000274754514100238, 0.000398861594001340, 0.000529984999270100, 0.000646117397525726, 0.000718766415753168,
  0.000716925008973219, 0.000612844047432097, 0.000388876459995003, 0.000043995168792169, -0.000401638582561071,
@@ -339,7 +339,7 @@ double quiskFilt133D5Coefs[235] = { 0.000017189993342429, 0.000044738485582654,
  0.000398861594001340, 0.000274754514100238, 0.000171520768649681, 0.000095017992345093, 0.000044738485582654,
  0.000017189993342429} ;
 
-// Sample 111111 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+// Sample 111111 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.21600.
 double quiskFilt111D2Coefs[114] = { 0.000039619752517087, 0.000089439819783633, 0.000017353012666121, -0.000334808345968833,
 -0.000892257134326630, -0.001221700854092078, -0.000859742027523152, 0.000086110163390211, 0.000794431841612731,
  0.000492910288706401, -0.000542730604541516, -0.001057738392194920, -0.000232619264909279, 0.001101735902638522,
@@ -364,7 +364,7 @@ double quiskFilt111D2Coefs[114] = { 0.000039619752517087, 0.000089439819783633,
  0.000492910288706401, 0.000794431841612731, 0.000086110163390211, -0.000859742027523152, -0.001221700854092078,
 -0.000892257134326630, -0.000334808345968833, 0.000017353012666121, 0.000089439819783633, 0.000039619752517087 } ;
 
-// Sample 111111 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
+// Sample 111111 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.10800.
 double quiskFilt111D4Coefs[196] = { 0.000022860383861326, 0.000070265173417164, 0.000160689233204503, 0.000301317969124407,
  0.000487289901409396, 0.000694724116305488, 0.000878636067621920, 0.000977522977076171, 0.000925771316840867,
  0.000672305339588912, 0.000201226295657756, -0.000452162019544330, -0.001196628260487459, -0.001896523042546486,
@@ -406,7 +406,7 @@ double quiskFilt111D4Coefs[196] = { 0.000022860383861326, 0.000070265173417164,
  0.000878636067621920, 0.000694724116305488, 0.000487289901409396, 0.000301317969124407, 0.000160689233204503,
  0.000070265173417164, 0.000022860383861326} ;
 
-// Sample 53333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.
+// Sample 53333 Hz, pass 20000, stop 24000, ripple 0.1 dB, atten 100 dB.  For SDR-IQ.  Stop 0.45000.
 double quiskFilt53D1Coefs[55] = { 0.000318858391362187, 0.001662116369387873, -0.000065237353639775, -0.000854885424783294,
  0.001693126335254083, -0.002034310867663472, 0.001354648789538254, 0.000509693525155950, -0.003079059747940221, 0.005242349925004462,
 -0.005626507739484119, 0.003235398612833476, 0.001883583294529978, -0.008273775245721798, 0.013282431836060808, -0.013924391581141530,
@@ -418,7 +418,7 @@ double quiskFilt53D1Coefs[55] = { 0.000318858391362187, 0.001662116369387873, -0
 -0.003079059747940221, 0.000509693525155950, 0.001354648789538254, -0.002034310867663472, 0.001693126335254083, -0.000854885424783294,
 -0.000065237353639775, 0.001662116369387873, 0.000318858391362187 } ;
 
-// Sample 53333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.
+// Sample 53333 Hz, pass 10000, stop 12000, ripple 0.5 dB, atten 100 dB.  For SDR-IQ.  Stop 0.22500.
 double quiskFilt53D2Coefs[93] = { 0.000107966318729964, 0.000421475598772498, 0.000731343669484184, 0.000328611865414609,
 -0.001457272471508304, -0.004143803290279123, -0.005736802939367581, -0.004303861070721504, -0.000415676176666607,
  0.002561521351129964, 0.001705074918770091, -0.001794491466202784, -0.003398011312785532, -0.000595401366072839,
@@ -440,7 +440,7 @@ double quiskFilt53D2Coefs[93] = { 0.000107966318729964, 0.000421475598772498, 0.
  0.000328611865414609, 0.000731343669484184, 0.000421475598772498, 0.000107966318729964} ;
 
 
-// Sample 240 kHz, pass 15, stop 23.9, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.
+// Sample 240 kHz, pass 15, stop 23.9, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.  Stop 0.09958.
 double quiskFilt240D5Coefs[114] = { -0.000017444714121896, -0.000043389176259008, -0.000086666475464372, -0.000143622066705595,
 -0.000204429258992282, -0.000250894192563019, -0.000258038648420713, -0.000198760816315186, -0.000051592624047688, 0.000190007232237523,
  0.000509003255256297, 0.000859996990289808, 0.001171187148400100, 0.001354817951508860, 0.001325999614958582, 0.001026888404781159,
@@ -462,7 +462,7 @@ double quiskFilt240D5Coefs[114] = { -0.000017444714121896, -0.000043389176259008
 -0.000198760816315186, -0.000258038648420713, -0.000250894192563019, -0.000204429258992282, -0.000143622066705595, -0.000086666475464372,
 -0.000043389176259008, -0.000017444714121896} ;
 
-// Sample 240 kHz, pass 20, stop 24, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.
+// Sample 240 kHz, pass 20, stop 24, ripple 0. 1dB, atten 100 dB, taps 114.  For 240 to 48 decimation by 5.  Stop 0.1000.
 double quiskFilt240D5CoefsSharp[246] = { 0.000011951828200011, 0.000019798433756403, 0.000028547330106604, 0.000030165284908057,
  0.000016460532579755, -0.000020835366942643, -0.000087256395370183, -0.000182447830402188, -0.000297836387286273,
 -0.000416082361724969, -0.000513090543707066, -0.000562800094080439, -0.000543922161049598, -0.000447038893351438,
@@ -514,7 +514,7 @@ double quiskFilt240D5CoefsSharp[246] = { 0.000011951828200011, 0.000019798433756
 -0.000087256395370183, -0.000020835366942643, 0.000016460532579755, 0.000030165284908057, 0.000028547330106604,
  0.000019798433756403, 0.000011951828200011 };
 
-// Sample 48 kHz, pass 10, stop 12, ripple 0.1 dB, atten 100 dB.
+// Sample 48 kHz, pass 10, stop 12, ripple 0.1 dB, atten 100 dB.  Stop 0.25000.
 double quiskFilt48dec24Coefs[98] = { 0.000036864882767612, 0.000009858596392836, -0.000330770380800406, -0.001009174072411182,
 -0.001404963853116591, -0.000770236458542885, 0.000523955998497470, 0.000947009978368078, -0.000170647420729277, -0.001215337186275615,
 -0.000339882761263432, 0.001380697691347411, 0.001052816245779061, -0.001289457483737270, -0.001905995022750999,
@@ -536,7 +536,7 @@ double quiskFilt48dec24Coefs[98] = { 0.000036864882767612, 0.000009858596392836,
  0.000947009978368078, 0.000523955998497470, -0.000770236458542885, -0.001404963853116591, -0.001009174072411182,
 -0.000330770380800406, 0.000009858596392836, 0.000036864882767612} ;
 
-// Sample 24 kHz, pass 4, stop 6, ripple 0.2 dB, atten 100 dB.
+// Sample 24 kHz, pass 4, stop 6, ripple 0.2 dB, atten 100 dB.  Stop 0.25000.
 double quiskAudio24p4Coefs[47] = { -0.000088032928341076, -0.000644655891856698, -0.001950684938386873, -0.003218845681314026,
 -0.002450782287864210, 0.001217506567762789, 0.004686926326285676, 0.002765800843238593, -0.004566450766965229, -0.008584510412060854,
 -0.000971556018221359, 0.012083832500170146, 0.012188815169382777, -0.007290936633701373, -0.024348624812992169, -0.010068583077594291,
@@ -547,7 +547,7 @@ double quiskAudio24p4Coefs[47] = { -0.000088032928341076, -0.000644655891856698,
  0.004686926326285676, 0.001217506567762789, -0.002450782287864210, -0.003218845681314026, -0.001950684938386873, -0.000644655891856698,
 -0.000088032928341076} ;
 
-// Sample 24 kHz, pass 6, stop 8, ripple 0.5 dB, atten 80 dB.
+// Sample 24 kHz, pass 6, stop 8, ripple 0.5 dB, atten 80 dB.  Stop 0.33333.
 double quiskAudio24p6Coefs[36] = { 0.001199140008010727, 0.005953815908571521, 0.008621055763448699, -0.000319602525571569,
 -0.008665733839154772, 0.003122601697996235, 0.011839435384729619, -0.008973143363910490, -0.014884256392667099, 0.019451226278492342,
  0.015232717446420085, -0.036364345084318225, -0.008723687718470995, 0.063232433222709966, -0.014104739941611717, -0.115885442639735490,
@@ -556,7 +556,7 @@ double quiskAudio24p6Coefs[36] = { 0.001199140008010727, 0.005953815908571521, 0
 -0.008973143363910490, 0.011839435384729619, 0.003122601697996235, -0.008665733839154772, -0.000319602525571569, 0.008621055763448699,
  0.005953815908571521, 0.001199140008010727} ;
 
-// Sample 48 kHz, pass 6, stop 8, ripple 0.5 dB, atten 80 dB.
+// Sample 48 kHz, pass 6, stop 8, ripple 0.5 dB, atten 80 dB.  Stop 0.16667.
 double quiskAudio48p6Coefs[71] = { 0.000324677779792651, 0.001038192405843851, 0.002082337464742640, 0.002938055116822665,
  0.002811674671240099, 0.001132278163758895, -0.001835394694865431, -0.004766409947196539, -0.005833007003128954, -0.003914015660218843,
  0.000296099005521212, 0.004239593489554206, 0.004918390640978499, 0.001100872619673516, -0.005241634309386784,
@@ -573,7 +573,7 @@ double quiskAudio48p6Coefs[71] = { 0.000324677779792651, 0.001038192405843851, 0
  0.001132278163758895, 0.002811674671240099, 0.002938055116822665, 0.002082337464742640, 0.001038192405843851,
  0.000324677779792651} ;
 
-// Sample 96 kHz, pass 6, stop 40, ripple 0.1 dB, atten 100 dB.
+// Sample 96 kHz, pass 6, stop 40, ripple 0.1 dB, atten 100 dB.  Stop 0.41667.
 double quiskAudio96Coefs[11] = { -0.004756607210954994, -0.022893760473075838, -0.023609616122334920,
  0.078161168368381481, 0.277880235815005590, 0.388489826271597950, 0.277880235815005590,
  0.078161168368381481, -0.023609616122334920, -0.022893760473075838, -0.004756607210954994} ;
@@ -633,7 +633,7 @@ double quiskAudioFmHpCoefs[309] = { 0.004847574947800705, -0.001211970386842814,
 -0.000365311474947399, -0.000434052387522716, -0.000504808183463150, -0.000579117971409598, -0.000658731927598885, -0.000745515693376396,
 -0.000841696354699768, -0.000949749961336003, -0.001072277374239886, -0.001211970386842814, 0.004847574947800705} ;
 
-// Sample 24 kHz, pass 3, stop 4, ripple 0.2 dB, atten 100 dB.
+// Sample 24 kHz, pass 3, stop 4, ripple 0.2 dB, atten 100 dB.  Stop 0.166667.
 double quiskAudio24p3Coefs[93] = { -0.000037783993624828, -0.000115216534351507, -0.000197004848051633, -0.000166882497461099,
  0.000128538373562514, 0.000763065896965353, 0.001593251408880778, 0.002221476977470587, 0.002159957821475971, 0.001165685783386774,
 -0.000455884791825150, -0.001852148041710624, -0.002061857791611326, -0.000704774303788570, 0.001548186623458437, 0.003181880133780748,
@@ -650,3 +650,40 @@ double quiskAudio24p3Coefs[93] = { -0.000037783993624828, -0.000115216534351507,
  0.002773578777222453, 0.003181880133780748, 0.001548186623458437, -0.000704774303788570, -0.002061857791611326, -0.001852148041710624,
 -0.000455884791825150, 0.001165685783386774, 0.002159957821475971, 0.002221476977470587, 0.001593251408880778, 0.000763065896965353,
  0.000128538373562514, -0.000166882497461099, -0.000197004848051633, -0.000115216534351507, -0.000037783993624828} ;
+
+// Sample 166.667 kHz, pass 20.000, stop 23.900, ripple 0.1dB, atten 100 dB.  Stop 0.143400.
+double quiskFilt167D3Coefs[173] = { 0.000027361057967466, 0.000079022927580003, 0.000153315280214681, 0.000217036303406228,
+ 0.000216051711988195, 0.000097396424148557, -0.000154926195574306, -0.000490420382204739, -0.000792207008833313,
+-0.000919092591781850, -0.000778111000786101, -0.000391274475742801, 0.000087636155699997, 0.000431036292372644,
+ 0.000453513042034128, 0.000127278368774421, -0.000375305195602114, -0.000754032727213185, -0.000745162366934028,
+-0.000291077295308464, 0.000391691804410550, 0.000907469994025008, 0.000906322210882447, 0.000315586781248832,
+-0.000570606431536495, -0.001224850102488048, -0.001191706572954991, -0.000392843729362266, 0.000766771909476392,
+ 0.001591024783572854, 0.001502286627641521, 0.000433072083786191, -0.001058714434132909, -0.002065657351825392,
+-0.001872596976495124, -0.000447193062325162, 0.001448204360826397, 0.002647575301181126, 0.002286703308575930,
+ 0.000403725700513730, -0.001971005587443560, -0.003359964169317242, -0.002743264224337261, -0.000278054902152837,
+ 0.002659789549535132, 0.004222291522979791, 0.003233725726619094, 0.000035039391335235, -0.003557779274022707,
+-0.005259805099663439, -0.003746914316541065, 0.000371441180756436, 0.004722776316977453, 0.006507912944025527,
+ 0.004270009795668968, -0.001002952818151785, -0.006235533234742016, -0.008019243636496016, -0.004787772358159753,
+ 0.001948724018108411, 0.008220101302576532, 0.009881282059334088, 0.005283717292111678, -0.003348783872543343,
+-0.010884795691042899, -0.012252153446073137, -0.005739902334679721, 0.005449960457274001, 0.014621846680862713,
+ 0.015450997622704835, 0.006140561144775123, -0.008746269854437872, -0.020270474363958398, -0.020205028153266937,
+-0.006470785151112811, 0.014438262597161191, 0.030022509645911820, 0.028563858550479816, 0.006716896161104373,
+-0.026463233531944890, -0.051946702805221123, -0.049198922096865508, -0.006868026781416496, 0.069760519092899292,
+ 0.158783283295639180, 0.229837831554147300, 0.256919080611963280, 0.229837831554147300, 0.158783283295639180,
+ 0.069760519092899292, -0.006868026781416496, -0.049198922096865508, -0.051946702805221123, -0.026463233531944890,
+ 0.006716896161104373, 0.028563858550479816, 0.030022509645911820, 0.014438262597161191, -0.006470785151112811,
+-0.020205028153266937, -0.020270474363958398, -0.008746269854437872, 0.006140561144775123, 0.015450997622704835,
+ 0.014621846680862713, 0.005449960457274001, -0.005739902334679721, -0.012252153446073137, -0.010884795691042899,
+-0.003348783872543343, 0.005283717292111678, 0.009881282059334088, 0.008220101302576532, 0.001948724018108411,
+-0.004787772358159753, -0.008019243636496016, -0.006235533234742016, -0.001002952818151785, 0.004270009795668968,
+ 0.006507912944025527, 0.004722776316977453, 0.000371441180756436, -0.003746914316541065, -0.005259805099663439,
+-0.003557779274022707, 0.000035039391335235, 0.003233725726619094, 0.004222291522979791, 0.002659789549535132,
+-0.000278054902152837, -0.002743264224337261, -0.003359964169317242, -0.001971005587443560, 0.000403725700513730,
+ 0.002286703308575930, 0.002647575301181126, 0.001448204360826397, -0.000447193062325162, -0.001872596976495124,
+-0.002065657351825392, -0.001058714434132909, 0.000433072083786191, 0.001502286627641521, 0.001591024783572854,
+ 0.000766771909476392, -0.000392843729362266, -0.001191706572954991, -0.001224850102488048, -0.000570606431536495,
+ 0.000315586781248832, 0.000906322210882447, 0.000907469994025008, 0.000391691804410550, -0.000291077295308464,
+-0.000745162366934028, -0.000754032727213185, -0.000375305195602114, 0.000127278368774421, 0.000453513042034128,
+ 0.000431036292372644, 0.000087636155699997, -0.000391274475742801, -0.000778111000786101, -0.000919092591781850,
+-0.000792207008833313, -0.000490420382204739, -0.000154926195574306, 0.000097396424148557, 0.000216051711988195,
+ 0.000217036303406228, 0.000153315280214681, 0.000079022927580003, 0.000027361057967466 } ;
