@@ -2,7 +2,9 @@
 # described in QEX and for the improved version HiQSDR.  To turn on the extended
 # features in HiQSDR, update your FPGA firmware to version 1.1 or later and use use_rx_udp = 2.
 
-import struct, socket, math
+from __future__ import print_function
+
+import struct, socket, math, traceback
 import _quisk as QS
 
 from quisk_hardware_model import Hardware as BaseHardware
@@ -73,10 +75,26 @@ class Hardware(BaseHardware):
     if self.conf.fft_size_multiplier == 0:
       self.conf.fft_size_multiplier = 7		# Set size needed by VarDecim
   def open(self):
-    self.rx_udp_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    self.rx_udp_socket.setblocking(0)
+    # Create the proper broadcast address for rx_udp_ip.
+    nm = self.conf.rx_udp_ip_netmask.split('.')
+    ip = self.conf.rx_udp_ip.split('.')
+    nm = map(int, nm)
+    ip = map(int, ip)
+    bc = ''
+    for i in range(4):
+      x = (ip[i] | ~ nm[i]) & 0xFF
+      bc = bc + str(x) + '.'
+    self.broadcast_addr = bc[:-1]
+    # This socket is used for the Simple Network Discovery Protocol by AE4JY
+    self.socket_sndp = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    self.socket_sndp.setblocking(0)
+    self.socket_sndp.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
+    self.sndp_request = chr(56) + chr(0) + chr(0x5A) + chr(0xA5) + chr(0) * 52
+    self.sndp_active = self.conf.sndp_active
     # conf.rx_udp_port is used for returning ADC samples
     # conf.rx_udp_port + 1 is used for control
+    self.rx_udp_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    self.rx_udp_socket.setblocking(0)
     self.rx_udp_socket.connect((self.conf.rx_udp_ip, self.conf.rx_udp_port + 1))
     return QS.open_rx_udp(self.conf.rx_udp_ip, self.conf.rx_udp_port)
   def close(self):
@@ -161,7 +179,7 @@ class Hardware(BaseHardware):
     else:
       self.HiQSDR_Attenuator = 0
       self.rf_gain = 0
-      print 'Unknown RfGain'
+      print ('Unknown RfGain')
     self.NewUdpStatus()
   def OnButtonPTT(self, event):
     # This feature requires firmware version 1.1 or higher
@@ -181,6 +199,21 @@ class Hardware(BaseHardware):
       self.HiQSDR_Bits &= ~0x01
     self.NewUdpStatus()
   def HeartBeat(self):
+    if self.sndp_active:	# AE4JY Simple Network Discovery Protocol - attempt to set the FPGA IP address
+      try:
+        self.socket_sndp.sendto(self.sndp_request, (self.broadcast_addr, 48321))
+        data = self.socket_sndp.recv(1024)
+        # print(repr(data))
+      except:
+        # traceback.print_exc()
+        pass
+      else:
+        if len(data) == 56 and data[5:14] == 'HiQSDR-v1':
+          ip = self.conf.rx_udp_ip.split('.')
+          t = (data[0:4] + chr(2) + data[5:37] + chr(int(ip[3])) + chr(int(ip[2])) + chr(int(ip[1])) + chr(int(ip[0]))
+               + chr(0) * 12 + chr(self.conf.rx_udp_port & 0xFF) + chr(self.conf.rx_udp_port >> 8) + chr(0))
+          # print(repr(t))
+          self.socket_sndp.sendto(t, (self.broadcast_addr, 48321))
     try:	# receive the old status if any
       data = self.rx_udp_socket.recv(1024)
       if DEBUG:
@@ -201,9 +234,10 @@ class Hardware(BaseHardware):
       else:		# We got a correct response.
         self.firmware_version = ord(self.got_udp_status[13])	# Firmware version is returned here
         if DEBUG:
-          print 'Got version',  self.firmware_version
+          print ('Got version',  self.firmware_version)
         if self.firmware_version > 0 and self.conf.use_rx_udp == 2:
           self.tx_control |= 0x04	# Use extra control bytes
+        self.sndp_active = False
         self.NewUdpStatus()
     else:
       if self.want_udp_status != self.got_udp_status:
@@ -217,15 +251,21 @@ class Hardware(BaseHardware):
       elif DEBUG:
         self.rx_udp_socket.send('Qs')
   def PrintStatus(self, msg, string):
-    print msg, ' ',
-    print string[0:2],
+    print (msg, ' ', end=' ')
+    print (string[0:2], end=' ')
     for c in string[2:]:
-      print "%2X" % ord(c),
-    print
+      print ("%2X" % ord(c), end=' ')
+    print ()
   def GetFirmwareVersion(self):
     return self.firmware_version
   def OnSpot(self, level):
     pass
+  def OnBtnFDX(self, is_fdx):   # Status of FDX button, 0 or 1
+    if is_fdx:
+      self.HiQSDR_Connector_X1 |= 0x20     # Mask in the FDX bit
+    else:
+      self.HiQSDR_Connector_X1 &= ~0x20
+    self.NewUdpStatus()
   def VarDecimGetChoices(self):		# return text labels for the control
     clock = self.conf.rx_udp_clock
     l = []			# a list of sample rates
