@@ -33,9 +33,6 @@ double quisk_mic_preemphasis;
 // Microphone clipping; try 3.0 or 4.0
 double quisk_mic_clip;
 
-#define MIC_AVG_GAIN	10.0	// Typical gain for the microphone in use
-#define MIC_MAX_GAIN	100.0	// Do not increase gain over this value
-
 // If true, decimate 48000 sps mic samples to 8000 sps for processing
 #define DECIM_8000	1
 
@@ -43,7 +40,9 @@ double quisk_mic_clip;
 int mic_max_display;			// display value of maximum microphone signal level 0 to 2**15 - 1
 
 static int mic_socket = INVALID_SOCKET;	// send microphone samples to a socket
-static int spotLevel = 0;		// 0 for no spotting; else the level 10 to 1000
+static int spotLevel = 0;				// 0 for no spotting; else the level 10 to 1000
+static double mic_avg_gain = 10.0;		// Typical gain for the microphone in use
+static double mic_max_gain = 100.0;		// Do not increase gain over this value
 
 static int mic_level;			// maximum microphone signal level for display
 static int mic_timer;			// time to display maximum mic level
@@ -190,7 +189,7 @@ static int tx_filter(complex * filtered, int count, int is_cpx)
 	complex csample;
 
 	static double x_1 = 0;
-	static double gainA = MIC_AVG_GAIN, gainB = 0.8;
+	static double gainA = 10.0, gainB = 0.8;
 	static double time_short, time_long;
 	static struct quisk_dFilter filter1={NULL}, filter2;
 	static struct quisk_cFilter filtDecim, filtInterp;
@@ -199,6 +198,7 @@ static int tx_filter(complex * filtered, int count, int is_cpx)
 	static double peakIn = 0, peakOut1 = 0, peakOut2 = 0, peakOut3 = 0;	// input/output level
 #endif
 	if (!filtered) {		// initialization
+        gainA = mic_avg_gain;
 		if (! filter1.dCoefs) {
 			if (quisk_sound_state.mic_sample_rate == 8000) {
 				sample_rate = 8000;
@@ -260,8 +260,8 @@ static int tx_filter(complex * filtered, int count, int is_cpx)
 		dtmp = cabs(csample);
 		if (dtmp != 0) {
 			gain = quisk_mic_clip / 2.5 / dtmp;	// target gain
-			if (gain > MIC_MAX_GAIN)
-				gain = MIC_MAX_GAIN;
+			if (gain > mic_max_gain)
+				gain = mic_max_gain;
 			if (gainA > gain)
 				gainA = gainA * (1 - time_short) + time_short * gain;	// gainA too high
 			else
@@ -723,6 +723,8 @@ void quisk_open_mic(void)
 #endif
 
 	modulation_index = QuiskGetConfigDouble("modulation_index", 1.6);
+	mic_max_gain = QuiskGetConfigDouble("mic_max_gain", 100.0);
+	mic_avg_gain = QuiskGetConfigDouble("mic_avg_gain", 10.0);
 	if (quisk_sound_state.tx_audio_port == 0x553B)
 		align4 = 0;		// Using old port: data starts at byte 42.
 	else
