@@ -8,12 +8,12 @@ if sys.platform == "win32":
   latency_millisecs = 150
   data_poll_usec = 20000
 else:
-  name_of_sound_capt = 'hw:0'  #'alsa:Audiophile'
-  name_of_sound_play = 'hw:0'    #"alsa:USB Audio CODEC"
+  name_of_sound_capt = 'alsa:CODEC USB'
+  name_of_sound_play = 'alsa:CODEC USB'
   latency_millisecs = 150
   data_poll_usec = 5000
 
-sdriq_name = "/dev/ttyUSB3"		# Name of the SDR-IQ device to open
+sdriq_name = "/dev/ttyUSB1"		# Name of the SDR-IQ device to open
 mic_clip = 3.0
 mic_preemphasis = 0.6
 
