@@ -17,14 +17,14 @@ elif 1:
   name_of_sound_capt = 'portaudio:Analog'
   name_of_sound_play = ''
   microphone_name = "portaudio:AK5370"
-  name_of_mic_play = 'portaudio:Analog'
+  name_of_mic_play = 'portaudio:CODEC USB'
   latency_millisecs = 150
   data_poll_usec = 5000
 else:
-  name_of_sound_capt = 'hw:0'
+  name_of_sound_capt = 'alsa:CODEC USB'
   name_of_sound_play = ''
   microphone_name = "alsa:AK5370"
-  name_of_mic_play = 'hw:0'
+  name_of_mic_play = 'alsa:CODEC USB'
   latency_millisecs = 50
   data_poll_usec = 5000
 
