@@ -2,6 +2,8 @@
 # that controls various hardware.  The files to control my 2010 transceiver
 # and for the improved version HiQSDR are in the package directory HiQSDR.
 
+from __future__ import print_function
+
 import sys, struct, math, socket, select, thread, time
 import _quisk as QS
 
@@ -308,7 +310,7 @@ class HwTx2007:
     pass
   def HeartBeat(self):
     if self.thread_msg:
-      print self.thread_msg
+      print (self.thread_msg)
       self.thread_msg = ''
 
 class HwRxEthVfo(BaseHardware):		# Ethernet control of VFO frequency
@@ -389,7 +391,7 @@ class LowPassFilter:	# Control my low pass filter box
       if self.timer <= 10:
         self.timer += 1
         if self.timer == 10:
-          print 'Low pass filter error'
+          print ('Low pass filter error')
       try:
         self.socket.send(self.want_data)
       except socket.error:
@@ -432,7 +434,7 @@ class HighPassFilter:	# Control my high pass filter box
     elif n == 3:	# -10
       self.preamp = 0x04
     else:
-      print 'Unknown RfGain'
+      print ('Unknown RfGain')
     self.SetTxFreq(None)
   def SetTxFreq(self, tx_freq):
     """Set high pass filter and preamp/attenuator state"""
@@ -496,7 +498,7 @@ class HighPassFilter:	# Control my high pass filter box
       if self.timer <= 10:
         self.timer += 1
         if self.timer == 10:
-          print 'High pass filter error'
+          print ('High pass filter error')
       try:
         self.socket.send(self.want_data)
       except socket.error:
@@ -540,7 +542,7 @@ class AntennaControl:	# Control my KI8BV dipole
       if self.timer <= 10:
         self.timer += 1
         if self.timer == 10:
-          print 'Antenna control error'
+          print ('Antenna control error')
       try:
         self.socket.send(self.want_data)
       except socket.error:
@@ -619,7 +621,7 @@ class AntennaTuner:		# Control an AT-200PC autotuner made by LDG
         self.Write(chr(40))		# Request ALLUPDATE
   def Write(self, s):		# Write a command string to the AT-200PC
     if DEBUG:
-      print 'Send', ord(s[0])
+      print ('Send', ord(s[0]))
     if self.serial:
       self.serial.setRTS(1)	# Wake up the AT-200PC
       time.sleep(0.003)		# Wait 3 milliseconds
@@ -643,7 +645,7 @@ class AntennaTuner:		# Control an AT-200PC autotuner made by LDG
         byte1 = self.rx_byte1
         byte2 = self.rx_byte2
         if DEBUG:
-          print 'Received', byte1, byte2, byte3
+          print ('Received', byte1, byte2, byte3)
         if byte1 > 19:			# Impossible command value
           continue
         if byte1 == 1 and self.set_L < 0:	# reported inductor value
