@@ -1,6 +1,9 @@
 # This file supports various hardware boxes at my shack
 
+from __future__ import print_function
+
 import sys, struct, math, socket, select, thread, time, traceback, os
+import cPickle
 import serial
 import _quisk as QS
 import wx
@@ -58,7 +61,7 @@ class LowPassFilter:	# Control my low pass filter box
       if self.timer <= 10:
         self.timer += 1
         if self.timer == 10:
-          print 'Low pass filter error'
+          print ('Low pass filter error')
       try:
         self.socket.send(self.want_data)
       except socket.error:
@@ -115,7 +118,7 @@ class HighPassFilter:	# Control my high pass filter box
       self.preamp = 0x04
       self.application.Hardware.rf_gain = -10
     else:
-      print 'Unknown RfGain'
+      print ('Unknown RfGain')
       self.application.Hardware.rf_gain = 0
     self.SetTxFreq(None)
   def SetTxFreq(self, tx_freq):
@@ -182,7 +185,7 @@ class HighPassFilter:	# Control my high pass filter box
       if self.timer <= 10:
         self.timer += 1
         if self.timer == 10:
-          print 'High pass filter error'
+          print ('High pass filter error')
       try:
         self.socket.send(self.want_data)
       except socket.error:
@@ -192,33 +195,27 @@ class HighPassFilter:	# Control my high pass filter box
 
 class AntennaControl:	# Control my KI8BV dipole
   AntCtrlAddress = ('192.168.2.194', 0x3A00 + 33)
-  index = {'20':0, '40':1, '60':2, '80':3}
-  def __init__(self, app, conf, address):
+  def __init__(self, app, conf):
     self.application = app	# Application instance (to provide attributes)
     self.conf = conf		# Config file module
-    if address:
-      self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-      self.socket.setblocking(0)
-      self.socket.connect(address)
-      self.have_data = None
-      self.want_data = '\00'
-      self.timer = 0
-    else:
-      self.socket = None
-  def ChangeBand(self, band):
-    if not self.socket:
-      return
+    self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    self.socket.setblocking(0)
+    self.socket.connect(self.AntCtrlAddress)
+    self.have_data = None
+    self.want_data = '\00'
     self.timer = 0
-    try:
-      self.want_data = chr(self.index[band])
-    except KeyError:
-      self.want_data = chr(3)
   def SetTxFreq(self, tx_freq):
-    pass
+    self.timer = 0
+    if tx_freq < 19000000:
+      self.want_data = '\03'
+    elif tx_freq < 22000000:
+      self.want_data = '\02'
+    elif tx_freq < 26500000:
+      self.want_data = '\01'
+    else:
+      self.want_data = '\00'
   def HeartBeat(self):
     global gatewayTime
-    if not self.socket:
-      return
     try:	# The antenna control box echoes its commands
       self.have_data = self.socket.recv(50)
     except socket.error:
@@ -227,18 +224,19 @@ class AntennaControl:	# Control my KI8BV dipole
       pass
     if self.have_data != self.want_data and time.time() - gatewayTime > gatewayLimit:
       gatewayTime = time.time()
-      if self.timer <= 10:
-        self.timer += 1
-        if self.timer == 10:
-          print 'Antenna control error'
+      self.timer += 1
+      if self.timer == 10:
+        print ('Antenna control error')
+        self.timer = 0
       try:
         self.socket.send(self.want_data)
+        # print ("Change dipole to ord %d" % ord(self.want_data))
       except socket.error:
         pass
       except socket.timeout:
         pass
 
-class AntennaTuner:     # Control my homebrew antenna tuner
+class AntennaTuner:     # Control my homebrew antenna tuner and my KI8BV dipole
   address = ('192.168.2.194', 0x3A00 + 47)
   def __init__(self, app, conf):
     self.application = app	# Application instance (to provide attributes)
@@ -247,17 +245,26 @@ class AntennaTuner:     # Control my homebrew antenna tuner
     self.GUI = None         # Control window
     self.have_data = chr(255) * 3
     self.tx_freq = 0
+    self.tune_freq = 0		# Frequency we last tuned
     self.disable_freq_control = False
     self.timer = 0
     self.set_L = 0
     self.set_C = 0
     self.set_HighZ = 0
-    self.antnum = 0         # Antenna number 0 or 1
+    self.antnum = 0				# Antenna number 0 or 1
+    self.fix_antnum = False		# Fix the antenna number
+    self.dipole2 = AntennaControl(app, conf)	# Control the KI8BV dipole
     if sys.platform == "win32":
-      self.TunerLC_fname = 'C:/pub/TunerLCZ.txt'
+      path = 'C:/pub/TunerLCZ.pkl'
     else:
-      self.TunerLC_fname = '/home/jim/pub/TunerLCZ.txt'
-    if hasattr(self.application, 'graph_freq'):
+      path = '/home/jim/pub/TunerLCZ.pkl'
+    try:
+      fp = open(path, "r")
+      self.TunerLC = cPickle.load(fp)
+      fp.close()
+    except IOError:
+      self.TunerLC = {}
+    if hasattr(self.application, 'is_vna_program'):
       self.is_vna = True
     else:
       self.is_vna = False
@@ -270,39 +277,21 @@ class AntennaTuner:     # Control my homebrew antenna tuner
     if self.antnum:
       flags |= 0x04
     self.want_data = chr(self.set_C) + chr(self.set_L) + chr(flags)
+    if self.set_HighZ:
+      hilo = 'HiZ'
+    else:
+      hilo = 'LoZ'
+    text = "L %3d,    C %3d,    %s,    Antenna %d" % (self.set_L, self.set_C, hilo, self.antnum)
     if self.GUI:
       self.GUI.sliderL.SetValue(self.set_L)
       self.GUI.sliderC.SetValue(self.set_C)
-      if self.set_HighZ:
-        hilo = 'HiZ'
-      else:
-        hilo = 'LoZ'
-      text = "L %3d,    C %3d,    %s" % (self.set_L, self.set_C, hilo)
-      #self.GUI.UpdateText(text)
+      self.GUI.UpdateText(text)
+    elif self.application.bottom_widgets:
+      self.application.bottom_widgets.UpdateText(text)
   def open(self):
     self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     self.socket.setblocking(0)
     self.socket.connect(self.address)
-    # TunerLC is a list of (freq, L, C, IsHi) for each antenna.
-    # The first and last entry for each antenna must have frequency 0 and 90000000.
-    self.TunerLC = ([], [])
-    try:
-      fp = open(self.TunerLC_fname, 'r')
-    except IOError:
-      self.TunerLC[0].append((0, 0, 0, 0))
-      self.TunerLC[0].append((90000000, 0, 0, 0))
-      self.TunerLC[1].append((0, 0, 0, 0))
-      self.TunerLC[1].append((90000000, 0, 0, 0))
-    else:
-      for line in fp:
-        line = line.split()
-        a = int(line[0])
-        f = int(line[1])
-        l = int(line[2])
-        c = int(line[3])
-        ishi = int(line[4])
-        self.TunerLC[a].append((f, l, c, ishi))
-      fp.close()
     if self.is_vna:
       self.GUI = AntTunerGUI(self, self.application)
       self.GUI.Show()
@@ -314,52 +303,43 @@ class AntennaTuner:     # Control my homebrew antenna tuner
     pass
   def SetTxFreq(self, tx_freq):
     self.tx_freq = tx_freq
+    if tx_freq is None:
+      return
+    if not self.fix_antnum:
+      if tx_freq < 17000000:
+        self.antnum = 0
+      else:
+        self.antnum = 1
+    if self.antnum == 1:
+      self.dipole2.SetTxFreq(tx_freq)
     if not self.socket:
       return
     if self.disable_freq_control:
       return
-    if tx_freq is None:
-      return
-    LC = self.TunerLC[self.antnum]
-    i1 = 0
-    i2 = len(LC) - 1
-    while 1:	# binary partition
-      i = (i1 + i2) / 2
-      if LC[i][0] < tx_freq:
-        i1 = i
-      else:
-        i2 = i
-      if i2 - i1 <= 1:
-        break
-    # The correct setting is between i1 and i2; interpolate
-    F1 = LC[i1][0]
-    F2 = LC[i2][0]
-    L1 = LC[i1][1]
-    L2 = LC[i2][1]
-    C1 = LC[i1][2]
-    C2 = LC[i2][2]
-    H1 = LC[i1][3]
-    H2 = LC[i2][3]
-    frac = (float(tx_freq) - F1) / (F2 - F1)
-    C = C1 + (C2 - C1) * frac
-    newC = int(C + 0.5)
-    L = L1 + (L2 - L1) * frac
-    newL = int(L + 0.5)
-    H = H1 + (H2 - H1) * frac
-    newH = int(H + 0.5)
-    # if not VNA, ignore small changes
-    if self.is_vna:
-      if newH != self.set_HighZ or self.set_C != newC or self.set_L != newL:
-        self.set_HighZ = newH
-        self.set_C = newC
-        self.set_L = newL
-        self.WantData()
-    else:
-      if newH != self.set_HighZ or abs(self.set_C - newC) + abs(self.set_L - newL) >= 2:
+    freq = (tx_freq + 5000) / 10000 * 10000		# rounded frequency
+    try:
+      newL, newC, newH = self.TunerLC[freq]
+    except KeyError:
+      newL, newC, newH = (0, 0, 0)
+    if newH != self.set_HighZ or self.set_C != newC or self.set_L != newL:
+      # if not VNA, ignore small changes in frequency
+      if self.is_vna or abs(self.tune_freq - tx_freq) > 5000:
+        self.tune_freq = tx_freq
         self.set_HighZ = newH
         self.set_C = newC
         self.set_L = newL
         self.WantData()
+  def OnAntTuner(self, text):	# One of the tuner buttons was pressed
+    if text == 'Antenna':
+      self.fix_antnum = False
+    elif text == 'Ant 0':
+      self.fix_antnum = True
+      self.antnum = 0
+    elif text == 'Ant 1':
+      self.fix_antnum = True
+      self.antnum = 1
+    self.SetTxFreq(self.tx_freq)
+    self.WantData()
   def HeartBeat(self):
     global gatewayTime
     if not self.socket:
@@ -373,22 +353,15 @@ class AntennaTuner:     # Control my homebrew antenna tuner
     if self.have_data != self.want_data and time.time() - gatewayTime > gatewayLimit:
       gatewayTime = time.time()
       self.Send()
-      if self.timer <= 10:
-        self.timer += 1
-        if self.timer == 10:
-          print 'Antenna tuner error'
-          self.timer = 0
+      self.timer += 1
+      if self.timer == 10:
+        print ('Antenna tuner error')
+        self.timer = 0
     else:
       self.timer = 0
-    if self.is_vna and self.application.graph_freq != self.tx_freq:
-      self.SetTxFreq(self.application.graph_freq)
-    if self.GUI and len(data) == 3:
-      if ord(data[2]) & 0x08:
-        hilo = 'LoZ'
-      else:
-        hilo = 'HiZ'
-      text = "L %3d,    C %3d,    %s" % (ord(data[1]), ord(data[0]), hilo)
-      self.GUI.UpdateText(text)
+    self.dipole2.HeartBeat()
+    if self.GUI:
+      self.GUI.HeartBeat()
   def Send(self):
     try:
       self.socket.send(self.want_data)
@@ -403,9 +376,10 @@ class AntTunerGUI(wx.Frame):    # Display a control window for my antenna tuner
        style=wx.STAY_ON_TOP|wx.CAPTION)
     self.anttuner = anttuner
     self.application = app
+    self.data_saving = False
     self.SetBackgroundColour('white')
     sizer = wx.GridBagSizer(hgap=5, vgap=3)
-    font = wx.Font(12, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+    font = wx.Font(12, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
     is_vna = anttuner.is_vna
     b = wx.StaticText(self, -1, "Adjust L", style=wx.ALIGN_CENTER)
     b.SetFont(font)
@@ -452,8 +426,60 @@ class AntTunerGUI(wx.Frame):    # Display a control window for my antenna tuner
       anttuner.set_HighZ = 1
     anttuner.WantData()
   def OnButtonSave(self, event):
+    self.data = []
+    self.data.append(tuple(self.application.graph.data_freq))
+    self.data_lcz = []
+    self.data_avg_freq = (self.application.graph.data_freq[0] + self.application.graph.data_freq[-1]) / 2
+    self.data_avg_freq = f = (self.data_avg_freq + 500000) / 1000000		# frequency rounded to megahertz
+    if f == 5:		# try to limit the number of L/C combinations
+      for HighZ in (0, ):
+        for L in range(0, 4):
+          for C in range(0, 61):
+            self.data_lcz.append((L, C, HighZ))
+    elif f == 7:
+      for HighZ in (0, ):
+        for L in range(0, 21):
+          for C in range(0, 91):
+            self.data_lcz.append((L, C, HighZ))
+    elif f == 10:
+      for HighZ in (0, ):
+        for L in range(0, 8):
+          for C in range(0, 91):
+            self.data_lcz.append((L, C, HighZ))
+    elif f == 14:
+      for HighZ in (0, ):
+        for L in range(0, 11):
+          for C in range(0, 21):
+            self.data_lcz.append((L, C, HighZ))
+    elif f == 18:
+      for HighZ in (0, ):
+        for L in range(0, 11):
+          for C in range(0, 11):
+            self.data_lcz.append((L, C, HighZ))
+    elif f == 21:
+      for HighZ in (0, ):
+        for L in range(0, 11):
+          for C in range(0, 11):
+            self.data_lcz.append((L, C, HighZ))
+    elif f == 25:
+      for HighZ in (0, 1):
+        for L in range(0, 11):
+          for C in range(0, 11):
+            self.data_lcz.append((L, C, HighZ))
+    elif 28 <= f <= 30:
+      for HighZ in (0, 1):
+        for L in range(0, 11):
+          for C in range(0, 15):
+            self.data_lcz.append((L, C, HighZ))
     anttuner = self.anttuner
-    freq = self.application.graph_freq
+    anttuner.set_L, anttuner.set_C, anttuner.set_HighZ = self.data_lcz[0]
+    del self.data_lcz[0]
+    anttuner.WantData()
+    self.data_saving = True
+    self.data_count = 0
+  def OnButtonSaveJIM(self, event):
+    anttuner = self.anttuner
+    freq = anttuner.tx_freq
     freq = (freq + 5000) / 10000 * 10000      # round
     LC = anttuner.TunerLC[anttuner.antnum]
     for i in range(len(LC)):	# Record new freq and L/C
@@ -482,6 +508,26 @@ class AntTunerGUI(wx.Frame):    # Display a control window for my antenna tuner
       for f, l, c, ishi in  lst:
         fp.write("%d %9d %4d %4d  %1d\n" % (i, f, l, c, ishi))
     fp.close()
+  def HeartBeat(self):
+    gr = self.application.graph
+    if self.data_saving:
+      anttuner = self.anttuner
+      if anttuner.have_data == anttuner.want_data:
+        self.data_count += 1
+        if self.data_count > 4:
+          self.data_count = 0
+          self.data.append(((anttuner.set_L, anttuner.set_C, anttuner.set_HighZ), tuple(self.application.graph.data_mag)))
+          #print ('record 500', (anttuner.set_L, anttuner.set_C, anttuner.set_HighZ), self.application.graph.data_mag[500])
+          if self.data_lcz:
+            anttuner.set_L, anttuner.set_C, anttuner.set_HighZ = self.data_lcz[0]
+            #print (self.data_lcz[0])
+            del self.data_lcz[0]
+            anttuner.WantData()
+          else:
+            self.data_saving = False
+            fp = open("/home/jim/pub/Tuner/data%2d.pkl" % self.data_avg_freq, "w")
+            cPickle.dump(self.data, fp)
+            fp.close()
 
 class AT200PC:		# Control an AT-200PC autotuner made by LDG
   def __init__(self, app, conf):
@@ -577,7 +623,7 @@ class AT200PC:		# Control an AT-200PC autotuner made by LDG
         self.Write(chr(40))		# Request ALLUPDATE
   def Write(self, s):		# Write a command string to the AT-200PC
     if DEBUG:
-      print 'Send', ord(s[0])
+      print ('Send', ord(s[0]))
     if self.serial:
       self.serial.setRTS(1)	# Wake up the AT-200PC
       time.sleep(0.003)		# Wait 3 milliseconds
@@ -601,7 +647,7 @@ class AT200PC:		# Control an AT-200PC autotuner made by LDG
         byte1 = self.rx_byte1
         byte2 = self.rx_byte2
         if DEBUG:
-          print 'Received', byte1, byte2, byte3
+          print ('Received', byte1, byte2, byte3)
         if byte1 > 19:			# Impossible command value
           continue
         if byte1 == 1 and self.set_L < 0:	# reported inductor value
