@@ -44,7 +44,9 @@ struct sound_dev {				// data for sound capture or playback device
 	int play_buf_size;			// size of playback buffer in samples
 	int use_float;				// DirectX: Use IEEE floating point
 	int dataPos;				// DirectX: data position
-	int started;				// DirectX: started flag
+	int oldPlayPos;				// DirectX: previous value of playPos
+	int play_delay;				// DirectX: bytes of sound available to play
+	int started;				// DirectX: started flag or state
 	int dev_error;				// read or write error
 	int dev_underrun;			// lack of samples to play
 	int dev_latency;			// latency frames
