@@ -41,6 +41,18 @@ default_screen = 'Graph'
 # of the space needed for all the buttons.
 graph_width = 0.8
 
+# The graph_width parameter controls the width of Quisk unless a larger width is forced.
+# If the Quisk screen is too wide or the buttons are too crowded, perhaps due to a low screen
+# resolution, you can reduce the font sizes.  Thanks to Christof, DJ4CM.
+button_font_size = 10
+# button_font_size = 9
+# button_font_size = 8
+default_font_size = 12
+status_font_size = 14
+config_font_size = 14
+graph_font_size = 10
+favorites_font_size = 14
+
 # This controls the speed of the graph peak hold.  Lower numbers give a longer time constant.
 graph_peak_hold_1 = 0.25
 graph_peak_hold_2 = 0.10
@@ -80,6 +92,66 @@ persistent_state = True
 # where your config file is located.
 favorites_file_path = ''
 
+# These control the typeface used in fonts.  The objective is to choose an available font that
+# offers good support for the Unicode characters used on buttons and windows.
+if sys.platform == "win32":
+  quisk_typeface = 'Lucida Sans Unicode'	# Typeface for quisk buttons and text
+  #quisk_typeface = 'Arial Unicode MS'
+else:
+  quisk_typeface = ''						# Use a default typeface
+
+# This controls whether the "U" symbols or the "T" symbols are used on buttons and windows.
+# You can change the "U" and "T" symbols to anything you want; either Unicode or text.
+use_unicode_symbols = True      # Use the symbols starting with "U"
+#use_unicode_symbols = False    # Use the symbols starting with "T"
+
+# These are the Unicode symbols used in the station window.  Thanks to Christof, DJ4CM.
+Usym_stat_fav = unichr(0x2605)	# Symbol for favorites, a star
+Usym_stat_mem = unichr(0x24C2)	# Symbol for memory stations, an "M" in a circle
+#Usym_stat_dx = unichr(0x2691)	# Symbol for DX Cluster stations, a flag
+Usym_stat_dx = unichr(0x25B2)	# Symbol for DX Cluster stations, a Delta
+# These are the text symbols used in the station window.
+Tsym_stat_fav = 'F'
+Tsym_stat_mem = 'M'
+Tsym_stat_dx = 'Dx'
+
+# These are the Unicode symbols to display on buttons.  Thanks to Christof, DJ4CM.
+Ubtn_text_range_dn = unichr(0x2190)      # Down band, left arrow
+Ubtn_text_range_up = unichr(0x2192)      # Up band, right arrow
+Ubtn_text_play = unichr(0x25BA)          # Play button
+Ubtn_text_rec = unichr(0x25CF)           # Record button, a filled dot
+Ubtn_text_file_rec = "File " + unichr(0x25CF)            # Record to file
+Ubtn_text_fav_add    = unichr(0x2605) + unichr(0x2191)   # Add to favorites
+Ubtn_text_fav_recall = unichr(0x2605) + unichr(0x2193)   # Jump to favorites screen
+Ubtn_text_mem_add  = unichr(0x24C2) + unichr(0x2191)     # Add to memory
+Ubtn_text_mem_next = unichr(0x24C2) + unichr(0x27B2)     # Next memory
+Ubtn_text_mem_del  = unichr(0x24C2) + unichr(0x2613)     # Delete from memory
+# These are the text symbols to display on buttons.
+Tbtn_text_range_dn = "Dn"
+Tbtn_text_range_up = "Up"
+Tbtn_text_play = "Play"
+Tbtn_text_rec = "Rec"
+Tbtn_text_file_rec = "File Rec"
+Tbtn_text_fav_add    = ">Fav"
+Tbtn_text_fav_recall = "Fav"
+Tbtn_text_mem_add  = "Save"
+Tbtn_text_mem_next = "Next"
+Tbtn_text_mem_del  = "Del"
+
+# Station info display configuration, thanks to DJ4CM.  This displays a window of station names
+# below the graph frequency (X axis).
+station_display_lines = 1		# number of station info display lines below the graph X axis
+#station_display_lines = 0
+#station_display_lines = 3
+
+# DX cluster telent login data, thanks to DJ4CM.  Must have station_display_lines > 0.
+dxClHost = ''					# host name for telnet server, null string to disable
+#dxClHost = 'example.host.net'
+dxClPort = 7373					# port number for telnet
+user_call_sign = 'CALL'			# your radio station call sign; probably needed for telnet login
+dxClPassword = None				# telnet password
+dxClExpireTime = 20				# Time in minutes until DX Cluster entries will be removed
+
 # This converts from dB to S-units for the S-meter (it is in S-units).
 correct_smeter = 15.5
 
@@ -94,6 +166,7 @@ display_fraction = 1.00
 max_record_minutes = 0.25
 
 # Thanks to Steve Murphy, KB8RWQ for the patch adding additional color control.
+# Thanks to Christof, DJ4CM for the patch adding additional color control. 
 # Define colors used by all widgets in wxPython colour format:
 color_bg			= 'light steel blue'	# Lower screen background
 color_graph			= 'lemonchiffon1'		# Graph background
@@ -108,13 +181,16 @@ color_cycle_btn		= 'goldenrod3'			# color of a cycle button when it is checked
 color_adjust_btn	= 'orange3'				# color of an adjustable button when it is checked
 color_test			= 'hot pink'			# color of a button used for test (turn off for tx)
 color_freq			= 'lightcyan1'			# background color of frequency and s-meter
+color_freq_txt      = 'black'               # text color of frequency display
 color_entry			= color_freq			# frequency entry box
+color_entry_txt     = 'black'		        # text color of entry box
 color_enable		= 'black'				# text color for an enabled button
 color_disable		= 'white'				# text color for a disabled button
 color_bandwidth		= 'lemonchiffon2'		# color for bandwidth display; thanks to WB4JFI
 #color_bandwidth = 'lemonchiffon3'
 color_txline		= 'red'					# vertical line color for tx in graph
 color_rxline		= 'green'				# vertical line color for rx in graph
+color_notebook_txt  = 'black'               # text of notebook lables
 
 # This is a dark color scheme designed by Steve Murphy, KB8RWQ.
 #color_bg                = '#111111'
@@ -130,15 +206,25 @@ color_rxline		= 'green'				# vertical line color for rx in graph
 #color_adjust_btn        = '#669999'
 #color_test              = 'hot pink'
 #color_freq              = '#333333'
+#color_freq_txt          = 'white'
 #color_entry             = color_freq
+#color_entry_txt         = color_freq_txt        # text color of entry box
 #color_enable            = 'white'
 #color_disable           = 'black'
 #color_bandwidth         = '#333333'
 #color_txline            = 'red'
 #color_rxline            = 'green'
+#color_notebook_txt      = 'white'               # text of notebook lables
 
 filter_display = 1	# Display the filter bandwidth on the graph screen; 0 or 1; thanks to WB4JFI
 
+# Quisk can operate in Split mode and can receive both the Tx and Rx frequency signals.  This option
+# controls where the sound goes.  You may need to try 1 or 2 depending on your wiring.
+#split_rxtx = 1		# Play both signals in stereo with the higher frequency on the real channel.
+split_rxtx = 2		# Play both signals in stereo with the lower frequency on the real channel.
+#split_rxtx = 3		# Play the receive signal on both channels.
+#split_rxtx = 4		# Play the transmit signal on both channels.
+
 # These are the palettes for the waterfall.  The one used is named waterfallPallette,
 # so to use a different one, overwrite this name in your .quisk_conf.py.
 waterfallPalette = (
@@ -239,6 +325,13 @@ HiQSDR_BandDict = {'160':1, '80':2, '40':3, '30':4, '20':5, '15':6, '17':7,
 # use_rx_udp = 1
 # For the newer HiQSDR hardware set this:
 # use_rx_udp = 2
+# For FPGA firmware version 1.4 and newer, the hardware is set to the rx_udp_ip you enter here.
+# For older firmware, the IP address is programmed into the FPGA, and you must enter that address as rx_udp_ip.
+rx_udp_ip = "192.168.2.196"				# Sample source IP address
+rx_udp_ip_netmask = '255.255.255.0'		# The netmask for the network of rx_udp_ip
+rx_udp_port = 0xBC77					# Sample source UDP port
+rx_udp_clock = 122880000				# ADC sample rate in Hertz
+sndp_active = True						# Enable setting the hardware IP to rx_udp_ip
 
 # Thanks to Ethan Blanton, KB8OJH, for this patch for the Si570 (many SoftRock's):
 # If you are using a DG8SAQ interface to set a Si570 clock directly, set
@@ -293,6 +386,7 @@ digital_input_name = ""		# device name for transmit audio
 # stereo at the same sample rate as the radio sound playback.
 digital_output_name = ""	# device name for received audio
 # digital_output_name = digital_input_name
+digital_output_level = 0.7		# This is the volume control 0.0 to 1.0 for digital playback to fldigi, etc.
 
 # You can control Quisk from Hamlib.  Set the Hamlib rig to 2 and the device for rig 2 to
 # localhost:4575, or other hamlib_port as used by Quisk.
@@ -331,6 +425,10 @@ tx_audio_port = 0			# UDP port for mic samples (or 0x553B)
 # For no mic audio processing, use mic_clip = 1.0; mic_preemphasis = 0.0
 mic_clip = 3.0				# Mic amplitude clipping; larger numbers give more clipping
 mic_preemphasis = 0.6		# Mic pre-emphasis 0.0 (none) to 1.0; or -1.0 for a Butterworth filter
+# These parameters control the microphone gain adjustment.
+mic_avg_gain = 10.0			# Typical gain for the microphone in use
+mic_max_gain = 100.0		# Do not increase gain over this value
+
 
 # If your mixing scheme inverts the RF spectrum, set this option to un-invert it
 invertSpectrum = 0
@@ -678,5 +776,8 @@ agc_max_gain = 15000.0
 # Reduce it if turning off the AGC makes the sound too loud.
 agc_off_gain = 1400.0
 
+# This is the AGC release time.  It must be greater than zero.
+agc_release_time = 0.3
+
 # For FM transmit, this is the modulation index.
 modulation_index = 1.67
