@@ -1,6 +1,6 @@
 # These are Quisk widgets
 
-import sys
+import sys, re
 import wx, wx.lib.buttons, wx.lib.stattext
 from types import *
 # The main script will alter quisk_conf_defaults to include the user's config file.
@@ -32,7 +32,7 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
          style=wx.ALIGN_CENTER|wx.ST_NO_AUTORESIZE)
     border = 4
     for points in range(30, 6, -1):
-      font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+      font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
       self.SetFont(font)
       w, h = self.GetTextExtent('333 444 555 Hz')
       if w < width and h < height - border * 2:
@@ -43,7 +43,13 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
     border = self.border = (height - self.height) / 2
     self.height_and_border = h + border * 2
     self.SetBackgroundColour(conf.color_freq)
-    self.SetForegroundColour(conf.color_enable)
+    self.SetForegroundColour(conf.color_freq_txt)
+    self.Bind(wx.EVT_LEFT_DOWN, self.OnLeftDown)	# Click on a digit changes the frequency
+    self.Bind(wx.EVT_LEFT_DCLICK, self.OnLeftDown)
+    self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
+    self.timer = wx.Timer(self)                     # Holding a digit continuously changes the frequency
+    self.Bind(wx.EVT_TIMER, self.OnTimer)
+    self.repeat_time = 0                           # Repeat function is inactive
   def Clip(self, clip):
     """Change color to indicate clipping."""
     if clip:
@@ -55,6 +61,60 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
     """Set the frequency to be displayed."""
     txt = FreqFormatter(freq)
     self.SetLabel('%s Hz' % txt)
+  def OnLeftDown(self, event):		# Click on a digit changes the frequency
+    if self.repeat_time:
+      self.timer.Stop()
+      self.repeat_time = 0
+    mouse_x, mouse_y = event.GetPosition()
+    width, height = self.GetClientSizeTuple()
+    if mouse_y < height / 2:
+      self.increase = True
+    else:
+      self.increase = False
+    text = self.GetLabel()
+    tw, th = self.GetTextExtent(text)
+    edge = (width - tw) / 2
+    digit = self.GetTextExtent('0')[0]
+    blank = self.GetTextExtent(' ')[0]
+    if mouse_x < edge - digit:
+      return
+    x = width - edge - self.GetTextExtent(" Hz")[0] - mouse_x
+    if x < 0:
+      return
+    #print ('size', width, height, 'mouse', mouse_x, mouse_y, 'digit', digit, 'blank', blank)
+    shift = 0
+    while x > digit * 3:
+      shift += 1
+      x -= digit * 3 + blank
+    if x < 0:
+      return
+    self.index = x / digit + shift * 3      # index of digit being changed
+    self.ChangeFreq()
+    self.repeat_time = 300		# first button push
+    self.timer.Start(milliseconds=300, oneShot=True)
+  def OnLeftUp(self, event):
+    self.timer.Stop()
+    self.repeat_time = 0
+  def ChangeFreq(self):
+    text = self.GetLabel()
+    text = text.replace(' ', '')[:-2]
+    text = text[:len(text)-self.index] + '0' * self.index
+    if self.increase:
+      freq = int(text) + 10 ** self.index
+    else:
+      freq = int(text) - 10 ** self.index
+      if freq <= 0 and self.index > 0:
+        freq = 10 ** (self.index - 1)
+    #print ('X', x, 'N', n, text, 'freq', freq)
+    application.ChangeRxTxFrequency(None, freq)
+  def OnTimer(self, event):
+    if self.repeat_time == 300:     # after first push, turn on repeats
+      self.repeat_time = 150
+    elif self.repeat_time > 20:
+      self.repeat_time -= 5
+    self.ChangeFreq()
+    self.timer.Start(milliseconds=self.repeat_time, oneShot=True)
+  
 
 class SliderBoxH:
   """A horizontal control with a slider and text with a value.  The text must have a %d if display is True."""
@@ -72,7 +132,9 @@ class SliderBoxH:
     else:
       t = self.text
     if pos is None:
-      self.text_ctrl = wx.StaticText(parent, -1, t)
+      self.text_ctrl = wx.StaticText(parent, -1, t, style=wx.ST_NO_AUTORESIZE)
+      w2, h2 = self.text_ctrl.GetSize()
+      self.text_ctrl.SetSizeHints(w2, -1, w2)
       self.slider = wx.Slider(parent, -1, init, themin, themax)
     else:
       self.text_ctrl = wx.StaticText(parent, -1, t, pos=pos)
@@ -102,9 +164,9 @@ class SliderBoxHH(SliderBoxH, wx.BoxSizer):
   def __init__(self, parent, text, init, themin, themax, handler, display):
     wx.BoxSizer.__init__(self, wx.HORIZONTAL)
     SliderBoxH.__init__(self, parent, text, init, themin, themax, handler, display, None, None)
-    #font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+    #font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
     #self.text_ctrl.SetFont(font)
-    self.Add(self.text_ctrl, 0, wx.ALIGN_CENTER|wx.FIXED_MINSIZE)
+    self.Add(self.text_ctrl, 0, wx.ALIGN_CENTER)
     self.Add(self.slider, 1, wx.ALIGN_CENTER)
 
 class SliderBoxV(wx.BoxSizer):
@@ -161,9 +223,9 @@ class _QuiskText1(wx.lib.stattext.GenStaticText):
     # Set decreasing point size until size_text fits in the space available
     for points in range(20, 6, -1):
       if self.fixed:
-        font = wx.Font(points, wx.FONTFAMILY_MODERN, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+        font = wx.Font(points, wx.FONTFAMILY_MODERN, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
       else:
-        font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+        font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
       dc.SetFont(font)
       w, h = dc.GetTextExtent(self.size_text)
       if w < width and h < height:
@@ -182,7 +244,7 @@ class _QuiskText1(wx.lib.stattext.GenStaticText):
     if not label:
       return
     if self.size_text:
-      self._MeasureFont(dc, width-4, height-4)
+      self._MeasureFont(dc, width-2, height-2)
     else:
       dc.SetFont(self.GetFont())
     if self.IsEnabled():
@@ -197,9 +259,9 @@ class _QuiskText1(wx.lib.stattext.GenStaticText):
     if style & wx.ALIGN_RIGHT:
       x = width - w - 4
     elif style & wx.ALIGN_CENTER:
-      x = (width - w)/2
+      x = (width - w - 1)/2
     else:
-      x = 4
+      x = 3
     dc.DrawText(label, x, y)
 
 class QuiskText(wx.BoxSizer):
@@ -227,7 +289,8 @@ class QuiskButtons:
     self.SetBezelWidth(self.button_bezel)
     self.SetBackgroundColour(conf.color_btn)
     self.SetUseFocusIndicator(False)
-    self.font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+    self.font = wx.Font(conf.button_font_size, wx.FONTFAMILY_SWISS, wx.NORMAL,
+             wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
     self.SetFont(self.font)
     if text:
       w, h = self.GetTextExtent(text)
@@ -240,16 +303,20 @@ class QuiskButtons:
     self.SetSizeHints(w, h, w * 6, h, 1, 1)
   def DrawLabel(self, dc, width, height, dx=0, dy=0):	# Override to change Disable text color
       dc.SetFont(self.GetFont())
-      if self.IsEnabled():
-          dc.SetTextForeground(conf.color_enable)
-      else:
-          dc.SetTextForeground(conf.color_disable)
-          #dc.SetTextForeground(wx.SystemSettings.GetColour(wx.SYS_COLOUR_GRAYTEXT))
       label = self.GetLabel()
       tw, th = dc.GetTextExtent(label)
-      if not self.up:
-          dx = dy = self.labelDelta
-      dc.DrawText(label, (width-tw)/2+dx, (height-th)/2+dy)
+      dx = dy = self.labelDelta
+      slabel = re.split('('+unichr(0x25CF)+')', label)	# unicode symbol for record: a filled dot
+      for part in slabel:		# This code makes the symbol red.  Thanks to Christof, DJ4CM.
+        if self.IsEnabled():
+          if part == unichr(0x25CF):
+            dc.SetTextForeground('red')
+          else:
+            dc.SetTextForeground(conf.color_enable)
+        else:
+          dc.SetTextForeground(conf.color_disable)
+        dc.DrawText(part, (width-tw)/2+dx, (height-th)/2+dy)
+        dx += dc.GetTextExtent(part)[0]
   def OnKeyDown(self, event):
     pass
   def OnKeyUp(self, event):
@@ -653,7 +720,7 @@ class FreqSetter(wx.TextCtrl):
     self.fmin = fmin
     self.fmax = fmax
     self.command = command
-    self.font = wx.Font(16, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL)
+    self.font = wx.Font(16, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
     t = wx.StaticText(parent, -1, label, pos=(x, y))
     t.SetFont(self.font)
     freq_w, freq_h = t.GetTextExtent(" 662 000 000")
