@@ -1,6 +1,8 @@
 # Please do not change this hardware control module.
 # It provides support for the SDR-IQ by RfSpace.
 
+from __future__ import print_function
+
 import _quisk as QS
 import sdriq
 
@@ -39,7 +41,7 @@ class Hardware(BaseHardware):
     elif n == 3:
       sdriq.gain_sdriq(1, 12)
     else:
-      print 'Unknown RfGain'
+      print ('Unknown RfGain')
   def ChangeFrequency(self, tune, vfo, source='', band='', event=None):
     if vfo:
       sdriq.freq_sdriq(vfo)
