@@ -19,6 +19,7 @@
 
 #include <complex.h>
 
+#define IMPORT_QUISK_API
 #include "quisk.h"
 #include "sdriq.h"
 
@@ -27,6 +28,10 @@
 // extension module for other hardware.  Read the end of this file for more
 // information.  This module was written by James Ahlstrom, N2ADR.
 
+// This module uses the Python interface to import symbols from the parent _quisk
+// extension module.  It must be linked with import_quisk_api.c.  See the documentation
+// at the start of import_quisk_api.c.
+
 // Start of SDR-IQ specific code:
 //
 #define DEBUG		0
@@ -73,7 +78,7 @@ static int Read(void * buf, int bufsize)
 		return 0;
 
 	if (FT_GetQueueStatus(quisk_sdriq_fd, &rx_bytes) != FT_OK) {
-		quisk_sound_state.read_error++;
+		pt_quisk_sound_state->read_error++;
 		return 0;
 	}
 	if (rx_bytes > bufsize)
@@ -85,7 +90,7 @@ static int Read(void * buf, int bufsize)
 		return bytes;
 	}
 	else {
-		quisk_sound_state.read_error++;
+		pt_quisk_sound_state->read_error++;
 		return 0;	
 	}
 }
@@ -116,7 +121,7 @@ static int Read(void * buf, int bufsize)
 	res = read(quisk_sdriq_fd, buf, bufsize);
 	if (res < 0) {
 		if (errno != EAGAIN && errno != EWOULDBLOCK) {
-			quisk_sound_state.read_error++;
+			pt_quisk_sound_state->read_error++;
 		}
 		return 0;
 	}
@@ -159,7 +164,7 @@ static void update_item(int item, const unsigned char * data)
 	case 5:
 		sdr_status = data[0];
 		if (data[0] == 0x20)
-			quisk_sound_state.overrange++;
+			pt_quisk_sound_state->overrange++;
 #if DEBUG
 		if (data[0] == 0x20)
 			printf ("Got overrange (clip)\n");
@@ -199,7 +204,7 @@ static void get_item(		// Host sends a request for a control item
 	if (nparams)
 		memcpy(buf + 4, params, nparams);
 	if (Write(buf, length) != length) {
-		quisk_sound_state.read_error++;
+		pt_quisk_sound_state->read_error++;
 #if DEBUG
 		printf("get_item write error\n");
 #endif
@@ -228,7 +233,7 @@ static void set_item(	// host command to set a control item
 	if (nparams)
 		memcpy(buf + 4, params, nparams);
 	if (Write(buf, length) != length) {
-		quisk_sound_state.read_error++;
+		pt_quisk_sound_state->read_error++;
 #if DEBUG
 		printf("set_item write error\n");
 #endif
@@ -245,7 +250,7 @@ static int sdr_recv(complex * samp, int sampsize)
 {		// Read all data from the SDR-IQ and process it.
 		// Return the number >= 0 of I/Q data samples that are available in samp.
 	int k, res, item, navail, nSamples;
-    short ii, qq;
+	short ii, qq;
 	unsigned char buf128[128];
 	static unsigned char buf[SDRIQ_BUF_SIZE];
 	static int iread=0;
@@ -391,7 +396,7 @@ start_here:
 		goto start_here;		// process the next state
 	}
 	else if (state == 9) {		// try to re-synchronize
-		quisk_sound_state.read_error++;
+		pt_quisk_sound_state->read_error++;
 #if DEBUG
 		printf ("Lost sync: type %d  length %d\n", type, length);
 #endif
@@ -450,7 +455,7 @@ static void set_ad6620(	// host command to set an AD6620 register
 	buf[7] = value & 0xFF;
 	buf[8] = 0;
 	if (Write(buf, 9) != 9) {
-		quisk_sound_state.read_error++;
+		pt_quisk_sound_state->read_error++;
 #if DEBUG
 		printf ("set_ad6620 write error\n");
 #endif
@@ -672,8 +677,8 @@ static void quisk_open_sdriq(const char * name, char * buf, int bufsize)
 			break;
 	}
 	set_item(0x0018, 4, "\x81\x01\x00\x00");
-    get_item(0x0002, 0, NULL);		// request serial number
-    get_item(0x0005, 0, NULL);		// request status
+	get_item(0x0002, 0, NULL);		// request serial number
+	get_item(0x0005, 0, NULL);		// request status
 	// set sample rate
 	freq = sdriq_clock;
 	buf1024[0] = 0;
@@ -685,7 +690,7 @@ static void quisk_open_sdriq(const char * name, char * buf, int bufsize)
 	freq = freq >> 8;
 	buf1024[4] = freq & 0xFF;
 	set_item(0x00B0, 5, buf1024);	// set actual clock speed
-    get_item(0x0001, 0, NULL);		// request name
+	get_item(0x0001, 0, NULL);		// request name
 	// loop for input
 	for (i = 0; i < SDRIQ_TIMEOUT; i++) {
 		sdr_recv(NULL, 0);
@@ -711,7 +716,7 @@ static void WaitForPoll(void)
 	static double time0 = 0;	// time in seconds
 	double timer;				// time remaining from last poll usec
 
-	timer = quisk_sound_state.data_poll_usec - (QuiskTimeSec() - time0) * 1e6;
+	timer = pt_quisk_sound_state->data_poll_usec - (QuiskTimeSec() - time0) * 1e6;
 	if (timer > 1000.0)	// see if enough time has elapsed
 		QuiskSleepMicrosec((int)timer);		// wait for the remainder of the poll interval
 	time0 = QuiskTimeSec();		// reset starting time value
@@ -813,9 +818,7 @@ static PyObject * open_samples(PyObject * self, PyObject * args)
 	sdriq_clock = QuiskGetConfigDouble("sdriq_clock", 66666667.0);
 
 // Record our C-language Start/Stop/Read functions for use by sound.c.
-	pt_sample_start = &quisk_start_sdriq;
-	pt_sample_stop = &quisk_stop_sdriq;
-	pt_sample_read = &quisk_read_sdriq;
+	quisk_sample_source(&quisk_start_sdriq, &quisk_stop_sdriq, &quisk_read_sdriq);
 //////////////
 	quisk_open_sdriq(name, buf, 128);		// SDR-IQ specific
 	return PyString_FromString(buf);		// return a string message
@@ -867,5 +870,13 @@ static PyMethodDef QuiskMethods[] = {
 // Initialization, and registration of public symbol "initsdriq":
 PyMODINIT_FUNC initsdriq (void)
 {
-	Py_InitModule ("sdriq", QuiskMethods);
+	if (Py_InitModule ("sdriq", QuiskMethods) == NULL) {
+		printf("Py_InitModule failed!\n");
+		return;
+	}
+	// Import pointers to functions and variables from module _quisk
+	if (import_quisk_api()) {
+		printf("Failure to import pointers from _quisk\n");
+		return;		//Error
+	}
 }
