@@ -41,6 +41,7 @@ static char file_name_samples[QUISK_PATH_SIZE];	// file name for recording sampl
 static int is_recording_audio;
 static int is_recording_samples;
 static int want_record;
+static double digital_output_level = 0.7;
 
 static ty_sample_start pt_sample_start;
 static ty_sample_stop  pt_sample_stop;
@@ -345,9 +346,9 @@ int quisk_read_sound(void)	// Called from sound thread
 		quisk_play_portaudio(&Playback, nSamples, cSamples, 1, quisk_audioVolume);
 	if (rxMode == 7 || rxMode == 8 || rxMode == 9) {
 		if (DigitalOutput.portaudio_index < 0)
-			quisk_play_alsa(&DigitalOutput, nSamples, cSamples, 0, 0.7);
+			quisk_play_alsa(&DigitalOutput, nSamples, cSamples, 0, digital_output_level);
 		else
-			quisk_play_portaudio(&DigitalOutput, nSamples, cSamples, 0, 0.7);
+			quisk_play_portaudio(&DigitalOutput, nSamples, cSamples, 0, digital_output_level);
 	}
 	// Perhaps record the speaker audio to a file
 	if (want_record) {
@@ -547,6 +548,7 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.channel_Q = 1;
 	// Playback device for digital modes
 	strncpy(DigitalOutput.name, QuiskGetConfigString ("digital_output_name", ""), QUISK_SC_SIZE);
+	digital_output_level = QuiskGetConfigDouble("digital_output_level", 0.7);
 	DigitalOutput.sample_rate = quisk_sound_state.playback_rate;	// Radio sound play rate
 	DigitalOutput.channel_I = 0;
 	DigitalOutput.channel_Q = 1;
