@@ -163,7 +163,7 @@ int quisk_read_alsa(struct sound_dev * dev, complex * cSamples)
 }
 
 void quisk_play_alsa(struct sound_dev * playdev, int nSamples,
-		complex * cSamples, int report_latency)
+		complex * cSamples, int report_latency, double volume)
 {	// Play the samples; write them to the ALSA soundcard.
 	int i, n, index;
 	snd_pcm_sframes_t frames, delay;
@@ -248,8 +248,8 @@ void quisk_play_alsa(struct sound_dev * playdev, int nSamples,
 	if (playdev->sample_bytes == 2) {
 		while (index < nSamples) {
 			for (i = 0, n = index; n < nSamples; i += playdev->num_channels, n++) {
-				ii = (int)(creal(cSamples[n]) / 65536);
-				qq = (int)(cimag(cSamples[n]) / 65536);
+				ii = (int)(volume * creal(cSamples[n]) / 65536);
+				qq = (int)(volume * cimag(cSamples[n]) / 65536);
 				buffer2[i + playdev->channel_I] = (short)ii;
 				buffer2[i + playdev->channel_Q] = (short)qq;
 			}
@@ -284,8 +284,8 @@ void quisk_play_alsa(struct sound_dev * playdev, int nSamples,
 	else if (playdev->sample_bytes == 3) {
 		while (index < nSamples) {
 			for (i = 0, n = index; n < nSamples; i += playdev->num_channels, n++) {
-				ii = (int)(creal(cSamples[n]) / 256);
-				qq = (int)(cimag(cSamples[n]) / 256);
+				ii = (int)(volume * creal(cSamples[n]) / 256);
+				qq = (int)(volume * cimag(cSamples[n]) / 256);
 				if (!is_little_endian) {	// convert to big-endian
 					buffer3[(i + playdev->channel_I) * 3    ] = *((unsigned char *)&ii + 2);
 					buffer3[(i + playdev->channel_Q) * 3    ] = *((unsigned char *)&qq + 2);
@@ -330,8 +330,8 @@ void quisk_play_alsa(struct sound_dev * playdev, int nSamples,
 	else if (playdev->sample_bytes == 4) {
 		while (index < nSamples) {
 			for (i = 0, n = index; n < nSamples; i += playdev->num_channels, n++) {
-				ii = (int)creal(cSamples[n]);
-				qq = (int)cimag(cSamples[n]);
+				ii = (int)(volume * creal(cSamples[n]));
+				qq = (int)(volume * cimag(cSamples[n]));
 				buffer4[i + playdev->channel_I] = ii;
 				buffer4[i + playdev->channel_Q] = qq;
 			}
