@@ -165,6 +165,8 @@ static int quisk_open_playback(struct sound_dev * dev)
 	dev->handle = NULL; 
 	dev->buffer = NULL; 
 	dev->started = 0;
+	dev->oldPlayPos = 0;
+	dev->play_delay = 0;
 	dev->dataPos = 0;
 	dev->portaudio_index = -1;
 	dev->sample_bytes = 2;
@@ -228,7 +230,7 @@ PyObject * quisk_sound_devices(PyObject * self, PyObject * args)
 
 void quisk_start_sound_alsa (struct sound_dev ** pCapture, struct sound_dev ** pPlayback)
 {
-    struct sound_dev * pDev;
+	struct sound_dev * pDev;
 
 	if (quisk_sound_state.err_msg[0])
 		return;		// prior error
@@ -263,7 +265,7 @@ void quisk_close_sound_alsa(struct sound_dev ** pCapture, struct sound_dev ** pP
 	while (*pPlayback) {
 		pDev = *pPlayback;
 		if (pDev->buffer)
-            IDirectSoundBuffer8_Stop((LPDIRECTSOUNDBUFFER)pDev->buffer);
+			IDirectSoundBuffer8_Stop((LPDIRECTSOUNDBUFFER)pDev->buffer);
 		pDev->handle = NULL;
 		pPlayback++;
 	}
@@ -433,90 +435,89 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 	DWORD playPos, writePos;	// hardware index into buffer
 	LPVOID pt1, pt2;
 	DWORD n1, n2;
-	int delay;
 	short * pts;
 	float * ptf;
 	int   * ptl;	// int must be 32 bits
-
-	int n, count, frames, bytes, pass, bytes_per_frame;
+	int n, unavail, count, frames, bytes, pass, bytes_per_frame;
 
 	if ( ! dev->handle || ! dev->buffer)
 		return;
 
 	bytes_per_frame = dev->num_channels * dev->sample_bytes;
+	// Note: writePos moves ahead with playPos; it is not associated with write activity
+	if (IDirectSoundBuffer8_GetCurrentPosition(ptBuf, &playPos, &writePos) != DS_OK) {
+#if DEBUG_IO
+		printf ("Bad GetCurrentPosition\n");
+#endif
+		quisk_sound_state.write_error++;
+		dev->dev_error++;
+		playPos = writePos = 0;
+	}
+	unavail = (int)writePos - (int)playPos;   // Must not write to this region
+	if (unavail < 0)
+		unavail += dev->play_buf_size;
+	count = (int)playPos - dev->oldPlayPos;     // number of bytes played
+	if (count < 0)
+		count += dev->play_buf_size;    // assume no wrap-around beyond play_buf_size
+	dev->oldPlayPos = playPos;
+	dev->play_delay -= count;                // bytes in buffer available to play
+	dev->dev_latency = dev->play_delay / bytes_per_frame;
+	if (report_latency)			// Report latency for main playback device
+		quisk_sound_state.latencyPlay = dev->dev_latency;
+#if DEBUG_IO
+	if (nSamples || count)
+		printf ("DirectX playPos %6d writePos %6d no-write %6d dev->dev_latency %6d data_pos %6d samples %6d\n",
+	    	(int)playPos, (int)writePos, unavail, dev->dev_latency, dev->dataPos, nSamples);
+#endif
+	switch(dev->started) {
+	case 0:     // Starting state; wait for buffer to fill before starting play
+		if (dev->dev_latency + nSamples >= dev->latency_frames) {
+			IDirectSoundBuffer8_Play (ptBuf, 0, 0, DSBPLAY_LOOPING);
+			dev->started = 1;
+#if DEBUG_IO
+		    printf ("Start DirectX play at dev->latency_frames %d\n", dev->latency_frames);
+#endif
+		}
+		break;
+	case 1:     // Normal run state
+		// Measure the space available to write samples
+		frames = (dev->play_buf_size - dev->play_delay - unavail) / bytes_per_frame;
+	    // Check for underrun
+	    n = unavail / bytes_per_frame + dev->latency_frames * 2 / 10 - nSamples;   // minimum frames
+	    if (dev->dev_latency < n) {
+		    quisk_sound_state.underrun_error++;
+		    dev->dev_underrun++;
+			n += dev->latency_frames * 2 / 10;
+			while (n-- > 0)
+				cSamples[nSamples++] = 0;   // add zero samples
+#if DEBUG_IO
+		    printf ("Underrun error, frames %d\n", dev->dev_latency);
+#endif
+	    }
+		// Check if play buffer is too full
+		else if (dev->dev_latency > dev->latency_frames * 18 / 10 || nSamples >= frames) {
+			quisk_sound_state.write_error++;
+			dev->dev_error++;
+			nSamples = 0;
+			dev->started = 2;
+#if DEBUG_IO
+			printf("Discard %d samples\n", nSamples);
+#endif
+		}
+		break;
+	case 2:     // Buffer is too full; wait for it to drain
+		nSamples = 0;
+		if (dev->dev_latency <= dev->latency_frames) {
+			dev->started = 1;
+#if DEBUG_IO
+			printf("Resume adding samples\n");
+#endif
+		}
+		break;
+	}
 	bytes = nSamples * bytes_per_frame;
 	if (bytes <= 0)
 		return;
-	if (dev->started) {
-		// Note: writePos moves ahead of playPos, not with write activity
-		if (IDirectSoundBuffer8_GetCurrentPosition(ptBuf, &playPos, &writePos) != DS_OK) {
-#if DEBUG_IO
-			printf ("Bad GetCurrentPosition\n");
-#endif
-			quisk_sound_state.write_error++;
-			dev->dev_error++;
-			playPos = writePos = 0;
-		}
-#if DEBUG_IO
-		if (dev->started < 10) {
-			dev->started++;
-			printf ("Initial playPos %d writePos %d frames %d\n",
-				(int)playPos, (int)writePos, (int)(writePos - playPos) / bytes_per_frame);
-		}
-#endif
-		if (dev->dataPos >= playPos)
-			count = dev->dataPos - playPos;
-		else
-			count = dev->dataPos - playPos + dev->play_buf_size;
-		delay = count / bytes_per_frame;	// frames in play buffer
-		dev->dev_latency = delay;
-		if (report_latency)			// Report latency for main playback device
-			quisk_sound_state.latencyPlay = delay;
-#if 0
-		if (nSamples + delay > dev->latency_frames * 9 / 10) {
-			nSamples--;
-#if DEBUG_IO
-			printf("Remove a sample nSamples %d  delay %d  total %d\n", nSamples, (int)delay, nSamples + (int)delay);
-#endif
-		}
-		else if(nSamples + delay < dev->latency_frames * 5 / 10) {
-			cSamples[nSamples] = cSamples[nSamples - 1];
-			nSamples++;
-#if DEBUG_IO
-			printf ("Add a sample nSamples %d  delay %d  total %d\n", nSamples, (int)delay, nSamples + (int)delay);
-#endif
-		}
-#endif
-		// Measure writePos to dataPos, the space available to write samples
-		if (dev->dataPos >= writePos)
-			count = dev->dataPos - writePos;
-		else
-			count = dev->dataPos - writePos + dev->play_buf_size;
-		frames = count / bytes_per_frame;	// frames after writePos excluding nSamples
-		// Check for underrun as indicated by excessive samples in two-second buffer
-		if (frames > dev->sample_rate) {	// more than one second of samples
-			quisk_sound_state.underrun_error++;
-			dev->dev_underrun++;
-			// write samples at write pointer + latency
-			dev->dataPos = writePos + (dev->latency_frames - nSamples) * bytes_per_frame;
-			dev->dataPos = dev->dataPos % dev->play_buf_size;
-#if DEBUG_IO
-			printf ("Underrun error, frames %d\n", frames);
-#endif
-		}
-		// Check if play buffer is too full
-		else if (frames + nSamples > dev->latency_frames * 15 / 10) {
-			quisk_sound_state.write_error++;
-			dev->dev_error++;
-			// write samples at write pointer + latency
-			dev->dataPos = writePos + (dev->latency_frames - nSamples) * bytes_per_frame;
-			dev->dataPos = dev->dataPos % dev->play_buf_size;
-#if DEBUG_IO
-			printf("Discard samples: frames %d exceed %d\n",
-				(int)frames, dev->latency_frames);
-#endif
-		}
-	}
 	// write our data bytes at our data position dataPos
 	if (IDirectSoundBuffer8_Lock(ptBuf, dev->dataPos, bytes, &pt1, &n1, &pt2, &n2, 0) != DS_OK) {
 #if DEBUG_IO
@@ -528,6 +529,7 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 	}
 	dev->dataPos += bytes;	// update data write position
 	dev->dataPos = dev->dataPos % dev->play_buf_size;
+	dev->play_delay += bytes;                // bytes available to play
 	pass = 0;
 	n = 0;
 	switch (dev->sample_bytes + dev->use_float) {
@@ -578,20 +580,6 @@ void quisk_play_alsa(struct sound_dev * dev, int nSamples,
 		break;
 	}
 	IDirectSoundBuffer8_Unlock(ptBuf, pt1, n1, pt2, n2);
-#if DEBUG_IO
-	if (n < nSamples)
-		printf ("Play error: Not all samples were played.\n");
-#endif
-	if ( ! dev->started) {	// check start threshold
-		frames = dev->dataPos / bytes_per_frame; // frames in play buffer
-#if DEBUG_IO
-		printf ("Start: %d %d\n", frames, dev->latency_frames);
-#endif
-		if (frames >= dev->latency_frames * 8 / 10) {
-			IDirectSoundBuffer8_Play (ptBuf, 0, 0, DSBPLAY_LOOPING);
-			dev->started = 1;
-		}
-	}
 }
 
 
