@@ -64,7 +64,7 @@ int quisk_read_portaudio(struct sound_dev * dev, complex * cSamples)
 }
 
 void quisk_play_portaudio(struct sound_dev * playdev, int nSamples, complex * cSamples,
-		int report_latency)
+		int report_latency, double volume)
 {	// play the samples; write them to the portaudio soundcard
 	int i, n, index;
 	long delay;
@@ -120,8 +120,8 @@ void quisk_play_portaudio(struct sound_dev * playdev, int nSamples, complex * cS
 			cSamples[nSamples++] = 0;
 	}
 	for (i = 0, n = index; n < nSamples; i += playdev->num_channels, n++) {
-		fi = creal(cSamples[n]);
-		fq = cimag(cSamples[n]);
+		fi = volume * creal(cSamples[n]);
+		fq = volume * cimag(cSamples[n]);
 		fbuffer[i + playdev->channel_I] = fi / CLIP32;
 		fbuffer[i + playdev->channel_Q] = fq / CLIP32;
 	}
